==> checker-3.23.0.jar: annotated-jdk/src/java.base/share/classes/java/util/UUID.java <==
/*
 * Copyright (c) 2003, 2014, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package java.util;

import org.checkerframework.checker.lock.qual.GuardSatisfied;
import org.checkerframework.checker.nullness.qual.Nullable;
import org.checkerframework.dataflow.qual.Pure;
import org.checkerframework.dataflow.qual.SideEffectFree;
import org.checkerframework.framework.qual.AnnotatedFor;
import java.security.*;
import jdk.internal.misc.JavaLangAccess;
import jdk.internal.misc.SharedSecrets;

@AnnotatedFor({ "lock", "nullness", "index" })
public final class UUID implements java.io.Serializable, Comparable<UUID> {

    private static class Holder {
    }

    public UUID(long mostSigBits, long leastSigBits) {
    }

    public static UUID randomUUID();

    public static UUID nameUUIDFromBytes(byte[] name);

    public static UUID fromString(String name);

    public long getLeastSignificantBits(@GuardSatisfied UUID this);

    public long getMostSignificantBits(@GuardSatisfied UUID this);

    public int version();

    public int variant();

    public long timestamp();

    public int clockSequence();

    public long node();

    @SideEffectFree
    public String toString(@GuardSatisfied UUID this);

    @Pure
    public int hashCode(@GuardSatisfied UUID this);

    @Pure
    public boolean equals(@GuardSatisfied UUID this, @GuardSatisfied @Nullable Object obj);

    @Pure
    public int compareTo(@GuardSatisfied UUID this, @GuardSatisfied UUID val);
}

==> checker-3.52.1.jar: annotated-jdk/src/java.base/share/classes/java/util/UUID.java <==
/*
 * Copyright (c) 2003, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package java.util;

import org.checkerframework.checker.lock.qual.GuardSatisfied;
import org.checkerframework.checker.nullness.qual.Nullable;
import org.checkerframework.dataflow.qual.Pure;
import org.checkerframework.dataflow.qual.SideEffectFree;
import org.checkerframework.framework.qual.AnnotatedFor;
import java.security.*;
import jdk.internal.access.JavaLangAccess;
import jdk.internal.access.SharedSecrets;

@AnnotatedFor({ "lock", "nullness", "index" })
public final class UUID implements java.io.Serializable, Comparable<UUID> {

    private static class Holder {
    }

    public UUID(long mostSigBits, long leastSigBits) {
    }

    public static UUID randomUUID();

    public static UUID nameUUIDFromBytes(byte[] name);

    public static UUID fromString(String name);

    public long getLeastSignificantBits(@GuardSatisfied UUID this);

    public long getMostSignificantBits(@GuardSatisfied UUID this);

    public int version();

    public int variant();

    public long timestamp();

    public int clockSequence();

    public long node();

    @SideEffectFree
    @Override
    public String toString(@GuardSatisfied UUID this);

    @Pure
    @Override
    public int hashCode(@GuardSatisfied UUID this);

    @Pure
    @Override
    public boolean equals(@GuardSatisfied UUID this, @GuardSatisfied @Nullable Object obj);

    @Pure
    @Override
    public int compareTo(@GuardSatisfied UUID this, @GuardSatisfied UUID val);
}
